[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Commits] r24790 - in /fsf/trunk/libc: ./ elf/ manual/ math/ sysdeps/i386/fpu/ sysdeps/ieee754/dbl-64/ sysdeps/sh/ sysdeps/sh/soft-fp/...
- To: commits@xxxxxxxxxx
- Subject: [Commits] r24790 - in /fsf/trunk/libc: ./ elf/ manual/ math/ sysdeps/i386/fpu/ sysdeps/ieee754/dbl-64/ sysdeps/sh/ sysdeps/sh/soft-fp/...
- From: eglibc@xxxxxxxxxx
- Date: Tue, 17 Dec 2013 08:02:10 -0000
Author: eglibc
Date: Tue Dec 17 00:02:09 2013
New Revision: 24790
Log:
Import glibc-mainline for 2013-12-17
Added:
fsf/trunk/libc/sysdeps/sh/s_fma.c
fsf/trunk/libc/sysdeps/sh/s_fmaf.c
fsf/trunk/libc/sysdeps/sh/soft-fp/
fsf/trunk/libc/sysdeps/sh/soft-fp/sfp-machine.h
Modified:
fsf/trunk/libc/ChangeLog
fsf/trunk/libc/NEWS
fsf/trunk/libc/configure
fsf/trunk/libc/configure.ac
fsf/trunk/libc/elf/dl-error.c
fsf/trunk/libc/manual/memory.texi
fsf/trunk/libc/math/auto-libm-test-in
fsf/trunk/libc/math/auto-libm-test-out
fsf/trunk/libc/math/gen-auto-libm-tests.c
fsf/trunk/libc/math/libm-test.inc
fsf/trunk/libc/sysdeps/i386/fpu/libm-test-ulps
fsf/trunk/libc/sysdeps/ieee754/dbl-64/s_sin.c
fsf/trunk/libc/sysdeps/sh/Implies
fsf/trunk/libc/sysdeps/x86_64/fpu/libm-test-ulps
Modified: fsf/trunk/libc/ChangeLog
==============================================================================
--- fsf/trunk/libc/ChangeLog (original)
+++ fsf/trunk/libc/ChangeLog Tue Dec 17 00:02:09 2013
@@ -1,4 +1,83 @@
+2013-12-16 Kaz Kojima <kkojima@xxxxxxxxxxxxxx>
+
+ [BZ #13304]
+ * sysdeps/sh/s_fma.c: New file.
+ * sysdeps/sh/s_fmaf.c: New file.
+ * sysdeps/sh/soft-fp/sfp-machine.h: New file. Based on arm
+ version.
+ * sysdeps/sh/Implies: Add sh/soft-fp.
+
+2013-12-16 Roland McGrath <roland@xxxxxxxxxxxxx>
+
+ * elf/dl-error.c (struct catch): Add new member `errcode'. Add a
+ level of indirection to members `objname', `errstring', `malloced'.
+ (_dl_signal_error): Store through pointers in *LCATCH rather modifying
+ *LCATCH itself. Set *LCATCH->errcode to ERRCODE rather than passing
+ it as the __longjmp argument (just pass 1 instead).
+ (_dl_catch_error): Initialize C with argument pointers and address of
+ volatile local ERRCODE rather than copying values out of C at return.
+
+2013-12-16 Joseph Myers <joseph@xxxxxxxxxxxxxxxx>
+
+ * math/auto-libm-test-in: Add tests of atan2, hypot and pow.
+ * math/auto-libm-test-out: Regenerated.
+ * math/libm-test.inc (atan2_test_data): Use AUTO_TESTS_ff_f.
+ (hypot_test_data): Likewise.
+ (pow_test_data): Likewise.
+ (pow_tonearest_test_data): Likewise.
+ * math/gen-auto-libm-tests.c (func_calc_method): Add value
+ mpfr_ff_f.
+ (func_calc_desc): Add mpfr_ff_f union field.
+ (FUNC_mpfr_ff_f): New macro.
+ (test_functions): Add atan2, hypot and pow.
+ (special_fill_min): New function.
+ (special_fill_minus_min): Likewise.
+ (special_fill_min_subnorm): Likewise.
+ (special_fill_minus_min_subnorm): Likewise.
+ (special_real_inputs): Add min, -min, min_subnorm and
+ -min_subnorm.
+ (calc_generic_results): Handle mpfr_ff_f.
+ * sysdeps/i386/fpu/libm-test-ulps: Update.
+ * sysdeps/x86_64/fpu/libm-test-ulps: Likewise.
+
+2013-12-16 Will Newton <will.newton@xxxxxxxxxx>
+
+ * manual/memory.texi (Malloc Examples): Mention aligned_alloc.
+ (Aligned Memory Blocks): Add documentation for aligned_alloc
+ and suggest it as an alternative to posix_memalign.
+ (Hooks for Malloc): Document __memalign_hook is also called
+ for aligned_alloc. (Summary of Malloc): Add summary for
+ aligned alloc. Document __memalign_hook is also called
+ for aligned_alloc.
+
+2013-12-16 Will Newton <will.newton@xxxxxxxxxx>
+
+ * manual/memory.texi (Malloc Examples): Clarify default
+ alignment documentation. Suggest posix_memalign rather
+ than memalign or valloc.
+ (Aligned Memory Blocks): Remove suggestion to use memalign
+ or valloc. Remove obsolete comment about BSD.
+ Document memalign errno values and mark the function obsolete.
+ Document posix_memalign returned error codes. Mark valloc
+ as obsolete. (Hooks for Malloc): __memalign_hook is also
+ called for posix_memalign and valloc.
+ (Summary of Malloc): Add posix_memalign to function summary.
+ __memalign_hook is also called for posix_memalign and valloc.
+
+2013-12-16 Siddhesh Poyarekar <siddhesh@xxxxxxxxxx>
+
+ * sysdeps/ieee754/dbl-64/s_sin.c (TAYLOR_SINCOS): Rename to
+ TAYLOR_SIN.
+ (__sin): Adjust.
+ (__cos): Likewise.
+ (sloww): Use mynumber union. Expand ternary operator into
+ if-else statements.
+ (cslow): use mynumber union.
+
2013-12-16 Allan McRae <allan@xxxxxxxxxxxxx>
+
+ * configure.ac: Set AUTOCONF when maintainer-mode is not used.
+ * configure: Regenerated.
* sysdeps/x86_64/multiarch/ifunc-impl-list.c: Update file name.
Modified: fsf/trunk/libc/NEWS
==============================================================================
--- fsf/trunk/libc/NEWS (original)
+++ fsf/trunk/libc/NEWS Tue Dec 17 00:02:09 2013
@@ -11,17 +11,18 @@
156, 387, 431, 832, 926, 2801, 4772, 6786, 6787, 6807, 6810, 7003, 9954,
10253, 10278, 11087, 11157, 11214, 12100, 12486, 13028, 13982, 13985,
- 14029, 14032, 14143, 14155, 14547, 14699, 14752, 14876, 14910, 15004,
- 15048, 15089, 15218, 15268, 15277, 15308, 15362, 15374, 15400, 15425,
- 15427, 15483, 15522, 15531, 15532, 15593, 15601, 15608, 15609, 15610,
- 15632, 15640, 15670, 15672, 15680, 15681, 15723, 15734, 15735, 15736,
- 15748, 15749, 15754, 15760, 15763, 15764, 15797, 15799, 15825, 15843,
- 15844, 15847, 15849, 15855, 15856, 15857, 15859, 15867, 15886, 15887,
- 15890, 15892, 15893, 15895, 15897, 15901, 15905, 15909, 15915, 15917,
- 15919, 15921, 15923, 15939, 15941, 15948, 15963, 15966, 15985, 15988,
- 15997, 16032, 16034, 16036, 16037, 16038, 16041, 16055, 16071, 16072,
- 16074, 16077, 16078, 16103, 16112, 16143, 16144, 16146, 16150, 16151,
- 16153, 16167, 16172, 16195, 16214, 16245, 16271, 16274, 16283, 16289.
+ 14029, 14032, 14120, 14143, 14155, 14547, 14699, 14752, 14876, 14910,
+ 15004, 15048, 15089, 15218, 15268, 15277, 15308, 15362, 15374, 15400,
+ 15425, 15427, 15483, 15522, 15531, 15532, 15593, 15601, 15608, 15609,
+ 15610, 15632, 15640, 15670, 15672, 15680, 15681, 15723, 15734, 15735,
+ 15736, 15748, 15749, 15754, 15760, 15763, 15764, 15797, 15799, 15825,
+ 15843, 15844, 15847, 15849, 15855, 15856, 15857, 15859, 15867, 15886,
+ 15887, 15890, 15892, 15893, 15895, 15897, 15901, 15905, 15909, 15915,
+ 15917, 15919, 15921, 15923, 15939, 15941, 15948, 15963, 15966, 15985,
+ 15988, 15997, 16032, 16034, 16036, 16037, 16038, 16041, 16055, 16071,
+ 16072, 16074, 16077, 16078, 16103, 16112, 16143, 16144, 16146, 16150,
+ 16151, 16153, 16167, 16172, 16195, 16214, 16245, 16271, 16274, 16283,
+ 16289.
* The public headers no longer use __unused nor __block. This change is to
support compiling programs that are derived from BSD sources and use
Modified: fsf/trunk/libc/configure
==============================================================================
--- fsf/trunk/libc/configure (original)
+++ fsf/trunk/libc/configure Tue Dec 17 00:02:09 2013
@@ -5198,6 +5198,8 @@
if test "x$AUTOCONF" = xno; then
aux_missing="$aux_missing autoconf"
fi
+else
+ AUTOCONF=no
fi
test -n "$critic_missing" && as_fn_error $? "
Modified: fsf/trunk/libc/configure.ac
==============================================================================
--- fsf/trunk/libc/configure.ac (original)
+++ fsf/trunk/libc/configure.ac Tue Dec 17 00:02:09 2013
@@ -1028,6 +1028,8 @@
if test "x$AUTOCONF" = xno; then
aux_missing="$aux_missing autoconf"
fi
+else
+ AUTOCONF=no
fi
test -n "$critic_missing" && AC_MSG_ERROR([
Modified: fsf/trunk/libc/elf/dl-error.c
==============================================================================
--- fsf/trunk/libc/manual/memory.texi (original)
+++ fsf/trunk/libc/manual/memory.texi Tue Dec 17 00:02:09 2013
@@ -380,10 +380,10 @@
The block that @code{malloc} gives you is guaranteed to be aligned so
that it can hold any type of data. On @gnusystems{}, the address is
-always a multiple of eight on most systems, and a multiple of 16 on
+always a multiple of eight on 32-bit systems, and a multiple of 16 on
64-bit systems. Only rarely is any higher boundary (such as a page
-boundary) necessary; for those cases, use @code{memalign},
-@code{posix_memalign} or @code{valloc} (@pxref{Aligned Memory Blocks}).
+boundary) necessary; for those cases, use @code{aligned_alloc} or
+@code{posix_memalign} (@pxref{Aligned Memory Blocks}).
Note that the memory located after the end of the block is likely to be
in use for something else; perhaps a block already allocated by another
@@ -616,14 +616,31 @@
The address of a block returned by @code{malloc} or @code{realloc} in
@gnusystems{} is always a multiple of eight (or sixteen on 64-bit
systems). If you need a block whose address is a multiple of a higher
-power of two than that, use @code{memalign}, @code{posix_memalign}, or
-@code{valloc}. @code{memalign} is declared in @file{malloc.h} and
-@code{posix_memalign} is declared in @file{stdlib.h}.
-
-With @theglibc{}, you can use @code{free} to free the blocks that
-@code{memalign}, @code{posix_memalign}, and @code{valloc} return. That
-does not work in BSD, however---BSD does not provide any way to free
-such blocks.
+power of two than that, use @code{aligned_alloc} or @code{posix_memalign}.
+@code{aligned_alloc} and @code{posix_memalign} are declared in
+@file{stdlib.h}.
+
+@comment stdlib.h
+@deftypefun {void *} aligned_alloc (size_t @var{alignment}, size_t @var{size})
+The @code{aligned_alloc} function allocates a block of @var{size} bytes whose
+address is a multiple of @var{alignment}. The @var{alignment} must be a
+power of two and @var{size} must be a multiple of @var{alignment}.
+
+The @code{aligned_alloc} function returns a null pointer on error and sets
+@code{errno} to one of the following values:
+
+@table @code
+@item ENOMEM
+There was insufficient memory available to satisfy the request.
+
+@item EINVAL
+@var{alignment} is not a power of two.
+
+This function was introduced in @w{ISO C11} and hence may have better
+portability to modern non-POSIX systems than @code{posix_memalign}.
+@end table
+
+@end deftypefun
@comment malloc.h
@comment BSD
@@ -633,6 +650,21 @@
power of two! The function @code{memalign} works by allocating a
somewhat larger block, and then returning an address within the block
that is on the specified boundary.
+
+The @code{memalign} function returns a null pointer on error and sets
+@code{errno} to one of the following values:
+
+@table @code
+@item ENOMEM
+There was insufficient memory available to satisfy the request.
+
+@item EINVAL
+@var{alignment} is not a power of two.
+
+@end table
+
+The @code{memalign} function is obsolete and @code{aligned_alloc} or
+@code{posix_memalign} should be used instead.
@end deftypefun
@comment stdlib.h
@@ -647,8 +679,20 @@
If the function succeeds in allocation memory a pointer to the allocated
memory is returned in @code{*@var{memptr}} and the return value is zero.
Otherwise the function returns an error value indicating the problem.
-
-This function was introduced in POSIX 1003.1d.
+The possible error values returned are:
+
+@table @code
+@item ENOMEM
+There was insufficient memory available to satisfy the request.
+
+@item EINVAL
+@var{alignment} is not a power of two multiple of @code{sizeof (void *)}.
+
+@end table
+
+This function was introduced in POSIX 1003.1d. Although this function is
+superseded by @code{aligned_alloc}, it is more portable to older POSIX
+systems that do not support @w{ISO C11}.
@end deftypefun
@comment malloc.h stdlib.h
@@ -667,6 +711,9 @@
@ref{Query Memory Parameters} for more information about the memory
subsystem.
+
+The @code{valloc} function is obsolete and @code{aligned_alloc} or
+@code{posix_memalign} should be used instead.
@end deftypefun
@node Malloc Tunable Parameters
@@ -902,16 +949,18 @@
@comment malloc.h
@comment GNU
@defvar __memalign_hook
-The value of this variable is a pointer to function that @code{memalign}
-uses whenever it is called. You should define this function to look
-like @code{memalign}; that is, like:
+The value of this variable is a pointer to function that @code{aligned_alloc},
+@code{memalign}, @code{posix_memalign} and @code{valloc} use whenever they
+are called. You should define this function to look like @code{aligned_alloc};
+that is, like:
@smallexample
void *@var{function} (size_t @var{alignment}, size_t @var{size}, const void *@var{caller})
@end smallexample
The value of @var{caller} is the return address found on the stack when
-the @code{memalign} function was called. This value allows you to trace the
+the @code{aligned_alloc}, @code{memalign}, @code{posix_memalign} or
+@code{valloc} functions are called. This value allows you to trace the
memory consumption of the program.
@end defvar
@@ -1118,6 +1167,14 @@
Allocate a block of @var{size} bytes, starting on a page boundary.
@xref{Aligned Memory Blocks}.
+@item void *aligned_alloc (size_t @var{size}, size_t @var{alignment})
+Allocate a block of @var{size} bytes, starting on an address that is a
+multiple of @var{alignment}. @xref{Aligned Memory Blocks}.
+
+@item int posix_memalign (void **@var{memptr}, size_t @var{alignment}, size_t @var{size})
+Allocate a block of @var{size} bytes, starting on an address that is a
+multiple of @var{alignment}. @xref{Aligned Memory Blocks}.
+
@item void *memalign (size_t @var{size}, size_t @var{boundary})
Allocate a block of @var{size} bytes, starting on an address that is a
multiple of @var{boundary}. @xref{Aligned Memory Blocks}.
@@ -1140,7 +1197,8 @@
A pointer to a function that @code{free} uses whenever it is called.
@item void (*__memalign_hook) (size_t @var{size}, size_t @var{alignment}, const void *@var{caller})
-A pointer to a function that @code{memalign} uses whenever it is called.
+A pointer to a function that @code{aligned_alloc}, @code{memalign},
+@code{posix_memalign} and @code{valloc} use whenever they are called.
@item struct mallinfo mallinfo (void)
Return information about the current dynamic memory usage.
Modified: fsf/trunk/libc/math/auto-libm-test-in
==============================================================================
--- fsf/trunk/libc/math/auto-libm-test-in (original)
+++ fsf/trunk/libc/math/auto-libm-test-in Tue Dec 17 00:02:09 2013
@@ -68,6 +68,38 @@
atan 0x1p-100 missing-underflow
atan 0x1p-600 missing-underflow
atan 0x1p-10000 missing-underflow
+
+# atan2 (0,x) == 0 for x > 0.
+atan2 0 1
+# atan2 (-0,x) == -0 for x > 0.
+atan2 -0 1
+atan2 0 0
+atan2 -0 0
+# atan2 (+0,x) == +pi for x < 0.
+atan2 0 -1
+# atan2 (-0,x) == -pi for x < 0.
+atan2 -0 -1
+atan2 0 -0
+atan2 -0 -0
+# atan2 (y,+0) == pi/2 for y > 0.
+atan2 1 0
+# atan2 (y,-0) == pi/2 for y > 0.
+atan2 1 -0
+# atan2 (y,+0) == -pi/2 for y < 0.
+atan2 -1 0
+# atan2 (y,-0) == -pi/2 for y < 0.
+atan2 -1 -0
+atan2 max max
+atan2 max min
+atan2 -max -min
+atan2 0.75 1
+atan2 -0.75 1.0
+atan2 0.75 -1.0
+atan2 -0.75 -1.0
+atan2 0.390625 .00029
+atan2 1.390625 0.9296875
+atan2 -0.00756827042671106339 -.001792735857538728036
+atan2 0x1.00000000000001p0 0x1.00000000000001p0
atanh 0
atanh -0
@@ -249,6 +281,35 @@
expm1 100000.0
expm1 max
expm1 -max
+
+# hypot (x,y) == hypot (+-x, +-y).
+hypot 0.7 12.4
+hypot -0.7 12.4
+hypot 0.7 -12.4
+hypot -0.7 -12.4
+hypot 12.4 0.7
+hypot -12.4 0.7
+hypot 12.4 -0.7
+hypot -12.4 -0.7
+# hypot (x,0) == fabs (x).
+hypot 0.75 0
+hypot -0.75 0
+hypot -5.7e7 0
+hypot 0.75 1.25
+hypot 1.0 0x1p-61
+hypot 0x1p+0 0x1.fp-129
+# Bug 16314: spurious underflow exception may occur.
+hypot 0x1.23456789abcdef0123456789ab8p-500 0x1.23456789abcdef0123456789ab8p-500 spurious-underflow:dbl-64
+hypot 0x3p125 0x4p125 no-test-inline:flt-32
+hypot 0x1.234566p-126 0x1.234566p-126 no-test-inline:flt-32
+hypot 0x3p1021 0x4p1021 no-test-inline:dbl-64
+hypot 0x1p+0 0x0.3ep-1022 no-test-inline:dbl-64
+hypot 0x3p16381 0x4p16381 no-test-inline
+hypot 0x1p-149 0x1p-149
+hypot 0x1p-1074 0x1p-1074
+# Bug 16316: hypot broken for some subnormal arguments.
+hypot 0x1p-16445 0x1p-16445 no-test-inline xfail:ldbl-96-intel xfail:ldbl-96-m68k
+hypot 0x1p-16494 0x1p-16494 no-test-inline xfail:ldbl-96-intel xfail:ldbl-96-m68k
j0 -1.0
j0 0.0
@@ -365,6 +426,298 @@
log2 16.0
log2 256.0
log2 0.75
+
+pow 0 0
+pow 0 -0
+pow -0 0
+pow -0 -0
+
+pow 10 0
+pow 10 -0
+pow -10 0
+pow -10 -0
+
+pow 1 1
+pow 1 -1
+pow 1 1.25
+pow 1 -1.25
+pow 1 0x1p62
+pow 1 0x1p63
+pow 1 0x1p64
+pow 1 0x1p72
+pow 1 min_subnorm
+pow 1 -min_subnorm
+
+# pow (x, +-0) == 1.
+pow 32.75 0
+pow 32.75 -0
+pow -32.75 0
+pow -32.75 -0
+pow 0x1p72 0
+pow 0x1p72 -0
+pow 0x1p-72 0
+pow 0x1p-72 -0
+
+pow 0x1p72 0x1p72
+pow 10 -0x1p72
+pow max max
+pow 10 -max
+
+pow 0 1
+pow 0 11
+
+pow -0 1
+pow -0 11
+
+pow 0 2
+pow 0 11.1
+
+pow -0 2
+pow -0 11.1
+
+# pow (+0, y) == +0 for y an odd integer > 0.
+pow 0.0 27
+pow 0.0 0xffffff
+pow 0.0 0x1.fffffffffffffp+52
+pow 0.0 0x1.fffffffffffffffep+63
+pow 0.0 0x1.ffffffffffffffffffffffffff8p+105
+pow 0.0 0x1.ffffffffffffffffffffffffffffp+112
+
+# pow (-0, y) == -0 for y an odd integer > 0.
+pow -0 27
+pow -0 0xffffff
+pow -0 0x1fffffe
+pow -0 0x1.fffffffffffffp+52
+pow -0 0x1.fffffffffffffp+53
+pow -0 0x1.fffffffffffffffep+63
+pow -0 0x1.fffffffffffffffep+64
+pow -0 0x1.ffffffffffffffffffffffffff8p+105
+pow -0 0x1.ffffffffffffffffffffffffff8p+106
+pow -0 0x1.ffffffffffffffffffffffffffffp+112
+pow -0 0x1.ffffffffffffffffffffffffffffp+113
+
+# pow (+0, y) == +0 for y > 0 and not an odd integer.
+pow 0.0 4
+pow 0.0 0x1p24
+pow 0.0 0x1p127
+pow 0.0 max
+pow 0.0 min_subnorm
+
+# pow (-0, y) == +0 for y > 0 and not an odd integer.
+pow -0 4
+pow -0 0x1p24
+pow -0 0x1p127
+pow -0 max
+pow -0 min_subnorm
+
+pow 16 0.25
+pow 0x1p64 0.125
+pow 2 4
+pow 256 8
+
+pow 0.75 1.25
+
+pow -7.49321e+133 -9.80818e+16
+
+pow -1.0 -0xffffff
+pow -1.0 -0x1fffffe
+pow -1.0 -0x1.fffffffffffffp+52
+pow -1.0 -0x1.fffffffffffffp+53
+pow -1.0 -0x1.fffffffffffffffep+63
+pow -1.0 -0x1.fffffffffffffffep+64
+pow -1.0 -0x1.ffffffffffffffffffffffffff8p+105
+pow -1.0 -0x1.ffffffffffffffffffffffffff8p+106
+pow -1.0 -0x1.ffffffffffffffffffffffffffffp+112
+pow -1.0 -0x1.ffffffffffffffffffffffffffffp+113
+pow -1.0 -max
+
+pow -1.0 0xffffff
+pow -1.0 0x1fffffe
+pow -1.0 0x1.fffffffffffffp+52
+pow -1.0 0x1.fffffffffffffp+53
+pow -1.0 0x1.fffffffffffffffep+63
+pow -1.0 0x1.fffffffffffffffep+64
+pow -1.0 0x1.ffffffffffffffffffffffffff8p+105
+pow -1.0 0x1.ffffffffffffffffffffffffff8p+106
+pow -1.0 0x1.ffffffffffffffffffffffffffffp+112
+pow -1.0 0x1.ffffffffffffffffffffffffffffp+113
+pow -1.0 max
+
+pow -2.0 126
+pow -2.0 127
+pow -2.0 -126
+pow -2.0 -127
+
+pow -2.0 -0xffffff
+pow -2.0 -0x1fffffe
+pow -2.0 -0x1.fffffffffffffp+52
+pow -2.0 -0x1.fffffffffffffp+53
+pow -2.0 -0x1.fffffffffffffffep+63
+pow -2.0 -0x1.fffffffffffffffep+64
+pow -2.0 -0x1.ffffffffffffffffffffffffff8p+105
+pow -2.0 -0x1.ffffffffffffffffffffffffff8p+106
+pow -2.0 -0x1.ffffffffffffffffffffffffffffp+112
+pow -2.0 -0x1.ffffffffffffffffffffffffffffp+113
+pow -2.0 -max
+
+pow -2.0 0xffffff
+pow -2.0 0x1fffffe
+pow -2.0 0x1.fffffffffffffp+52
+pow -2.0 0x1.fffffffffffffp+53
+pow -2.0 0x1.fffffffffffffffep+63
+pow -2.0 0x1.fffffffffffffffep+64
+pow -2.0 0x1.ffffffffffffffffffffffffff8p+105
+pow -2.0 0x1.ffffffffffffffffffffffffff8p+106
+pow -2.0 0x1.ffffffffffffffffffffffffffffp+112
+pow -2.0 0x1.ffffffffffffffffffffffffffffp+113
+pow -2.0 max
+
+pow -max -2
+pow -max -3
+pow -max 2
+pow -max 3
+
+pow -max -0xffffff
+pow -max -0x1fffffe
+pow -max -0x1.fffffffffffffp+52
+pow -max -0x1.fffffffffffffp+53
+pow -max -0x1.fffffffffffffffep+63
+pow -max -0x1.fffffffffffffffep+64
+pow -max -0x1.ffffffffffffffffffffffffff8p+105
+pow -max -0x1.ffffffffffffffffffffffffff8p+106
+pow -max -0x1.ffffffffffffffffffffffffffffp+112
+pow -max -0x1.ffffffffffffffffffffffffffffp+113
+pow -max -max
+
+pow -max 0xffffff
+pow -max 0x1fffffe
+pow -max 0x1.fffffffffffffp+52
+pow -max 0x1.fffffffffffffp+53
+pow -max 0x1.fffffffffffffffep+63
+pow -max 0x1.fffffffffffffffep+64
+pow -max 0x1.ffffffffffffffffffffffffff8p+105
+pow -max 0x1.ffffffffffffffffffffffffff8p+106
+pow -max 0x1.ffffffffffffffffffffffffffffp+112
+pow -max 0x1.ffffffffffffffffffffffffffffp+113
+pow -max max
+
+pow -0.5 126
+pow -0.5 127
+pow -0.5 -126
+pow -0.5 -127
+
+pow -0.5 -0xffffff
+pow -0.5 -0x1fffffe
+pow -0.5 -0x1.fffffffffffffp+52
+pow -0.5 -0x1.fffffffffffffp+53
+pow -0.5 -0x1.fffffffffffffffep+63
+pow -0.5 -0x1.fffffffffffffffep+64
+pow -0.5 -0x1.ffffffffffffffffffffffffff8p+105
+pow -0.5 -0x1.ffffffffffffffffffffffffff8p+106
+pow -0.5 -0x1.ffffffffffffffffffffffffffffp+112
+pow -0.5 -0x1.ffffffffffffffffffffffffffffp+113
+pow -0.5 -max
+
+pow -0.5 0xffffff
+pow -0.5 0x1fffffe
+pow -0.5 0x1.fffffffffffffp+52
+pow -0.5 0x1.fffffffffffffp+53
+pow -0.5 0x1.fffffffffffffffep+63
+pow -0.5 0x1.fffffffffffffffep+64
+pow -0.5 0x1.ffffffffffffffffffffffffff8p+105
+pow -0.5 0x1.ffffffffffffffffffffffffff8p+106
+pow -0.5 0x1.ffffffffffffffffffffffffffffp+112
+pow -0.5 0x1.ffffffffffffffffffffffffffffp+113
+pow -0.5 max
+
+pow -min -2
+pow -min -3
+pow -min 1
+pow -min 2
+pow -min 3
+
+pow -min -0xffffff
+pow -min -0x1fffffe
+pow -min -0x1.fffffffffffffp+52
+pow -min -0x1.fffffffffffffp+53
+pow -min -0x1.fffffffffffffffep+63
+pow -min -0x1.fffffffffffffffep+64
+pow -min -0x1.ffffffffffffffffffffffffff8p+105
+pow -min -0x1.ffffffffffffffffffffffffff8p+106
+pow -min -0x1.ffffffffffffffffffffffffffffp+112
+pow -min -0x1.ffffffffffffffffffffffffffffp+113
+pow -min -max
+
+pow -min 0xffffff
+pow -min 0x1fffffe
+pow -min 0x1.fffffffffffffp+52
+pow -min 0x1.fffffffffffffp+53
+pow -min 0x1.fffffffffffffffep+63
+pow -min 0x1.fffffffffffffffep+64
+pow -min 0x1.ffffffffffffffffffffffffff8p+105
+pow -min 0x1.ffffffffffffffffffffffffff8p+106
+pow -min 0x1.ffffffffffffffffffffffffffffp+112
+pow -min 0x1.ffffffffffffffffffffffffffffp+113
+pow -min max
+
+pow 0x0.ffffffp0 10
+pow 0x0.ffffffp0 100
+pow 0x0.ffffffp0 1000
+pow 0x0.ffffffp0 0x1p24
+pow 0x0.ffffffp0 0x1p30
+pow 0x0.ffffffp0 0x1.234566p30
+pow 0x0.ffffffp0 -10
+pow 0x0.ffffffp0 -100
+pow 0x0.ffffffp0 -1000
+pow 0x0.ffffffp0 -0x1p24
+pow 0x0.ffffffp0 -0x1p30
+pow 0x0.ffffffp0 -0x1.234566p30
+pow 0x1.000002p0 0x1p24
+pow 0x1.000002p0 0x1.234566p29
+pow 0x1.000002p0 -0x1.234566p29
+
+pow 0x0.fffffffffffff8p0 0x1.23456789abcdfp62
+pow 0x0.fffffffffffff8p0 -0x1.23456789abcdfp62
+pow 0x1.0000000000001p0 0x1.23456789abcdfp61
+pow 0x1.0000000000001p0 -0x1.23456789abcdfp61
+
+pow 0x0.ffffffffffffffffp0 0x1.23456789abcdef0ep77
+pow 0x0.ffffffffffffffffp0 -0x1.23456789abcdef0ep77
+pow 0x1.0000000000000002p0 0x1.23456789abcdef0ep76
+pow 0x1.0000000000000002p0 -0x1.23456789abcdef0ep76
+
+pow 0x0.ffffffffffffffffffffffffffff8p0 0x1.23456789abcdef0123456789abcdp126
+pow 0x0.ffffffffffffffffffffffffffff8p0 -0x1.23456789abcdef0123456789abcdp126
+pow 0x1.0000000000000000000000000001p0 0x1.23456789abcdef0123456789abcdp125
+pow 0x1.0000000000000000000000000001p0 -0x1.23456789abcdef0123456789abcdp125
+
+pow 1e4932 0.75
+pow 1e4928 0.75
+pow 1e4924 0.75
+pow 1e4920 0.75
+pow 10.0 4932.0
+pow 10.0 4931.0
+pow 10.0 4930.0
+pow 10.0 4929.0
+pow 10.0 -4931.0
+pow 10.0 -4930.0
+pow 10.0 -4929.0
+pow 1e27 182.0
+pow 1e27 -182.0
+
+pow min_subnorm min_subnorm
+pow min_subnorm -min_subnorm
+pow max min_subnorm
+pow max -min_subnorm
+pow 0.99 min_subnorm
+pow 0.99 -min_subnorm
+pow 1.01 min_subnorm
+pow 1.01 -min_subnorm
+
+pow 2.0 -100000.0
+
+pow 1.0625 1.125
+pow 1.5 1.03125
sin 0
sin -0
Modified: fsf/trunk/libc/math/auto-libm-test-out
==============================================================================
--- fsf/trunk/libc/math/auto-libm-test-out (original)
+++ fsf/trunk/libc/math/auto-libm-test-out Tue Dec 17 00:02:09 2013
@@ -2073,6 +2073,2709 @@
= atan tonearest ldbl-128 0x1p-10000L : 0x1p-10000L : inexact-ok
= atan towardzero ldbl-128 0x1p-10000L : 0xf.fffffffffffffffffffffffffff8p-10004L : inexact-ok
= atan upward ldbl-128 0x1p-10000L : 0x1p-10000L : inexact-ok
+atan2 0 1
+= atan2 downward flt-32 0x0p+0f 0x1p+0f : 0x0p+0f : inexact-ok
+= atan2 tonearest flt-32 0x0p+0f 0x1p+0f : 0x0p+0f : inexact-ok
+= atan2 towardzero flt-32 0x0p+0f 0x1p+0f : 0x0p+0f : inexact-ok
+= atan2 upward flt-32 0x0p+0f 0x1p+0f : 0x0p+0f : inexact-ok
+= atan2 downward dbl-64 0x0p+0 0x1p+0 : 0x0p+0 : inexact-ok
+= atan2 tonearest dbl-64 0x0p+0 0x1p+0 : 0x0p+0 : inexact-ok
+= atan2 towardzero dbl-64 0x0p+0 0x1p+0 : 0x0p+0 : inexact-ok
+= atan2 upward dbl-64 0x0p+0 0x1p+0 : 0x0p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 downward ldbl-128 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 upward ldbl-128 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0x0p+0L 0x1p+0L : 0x0p+0L : inexact-ok
+atan2 -0 1
+= atan2 downward flt-32 -0x0p+0f 0x1p+0f : -0x0p+0f : inexact-ok
+= atan2 tonearest flt-32 -0x0p+0f 0x1p+0f : -0x0p+0f : inexact-ok
+= atan2 towardzero flt-32 -0x0p+0f 0x1p+0f : -0x0p+0f : inexact-ok
+= atan2 upward flt-32 -0x0p+0f 0x1p+0f : -0x0p+0f : inexact-ok
+= atan2 downward dbl-64 -0x0p+0 0x1p+0 : -0x0p+0 : inexact-ok
+= atan2 tonearest dbl-64 -0x0p+0 0x1p+0 : -0x0p+0 : inexact-ok
+= atan2 towardzero dbl-64 -0x0p+0 0x1p+0 : -0x0p+0 : inexact-ok
+= atan2 upward dbl-64 -0x0p+0 0x1p+0 : -0x0p+0 : inexact-ok
+= atan2 downward ldbl-96-intel -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 upward ldbl-96-intel -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 downward ldbl-96-m68k -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 downward ldbl-128 -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-128 -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-128 -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 upward ldbl-128 -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 downward ldbl-128ibm -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+= atan2 upward ldbl-128ibm -0x0p+0L 0x1p+0L : -0x0p+0L : inexact-ok
+atan2 0 0
+= atan2 downward flt-32 0x0p+0f 0x0p+0f : 0x0p+0f : inexact-ok
+= atan2 tonearest flt-32 0x0p+0f 0x0p+0f : 0x0p+0f : inexact-ok
+= atan2 towardzero flt-32 0x0p+0f 0x0p+0f : 0x0p+0f : inexact-ok
+= atan2 upward flt-32 0x0p+0f 0x0p+0f : 0x0p+0f : inexact-ok
+= atan2 downward dbl-64 0x0p+0 0x0p+0 : 0x0p+0 : inexact-ok
+= atan2 tonearest dbl-64 0x0p+0 0x0p+0 : 0x0p+0 : inexact-ok
+= atan2 towardzero dbl-64 0x0p+0 0x0p+0 : 0x0p+0 : inexact-ok
+= atan2 upward dbl-64 0x0p+0 0x0p+0 : 0x0p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 downward ldbl-128 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 upward ldbl-128 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0x0p+0L 0x0p+0L : 0x0p+0L : inexact-ok
+atan2 -0 0
+= atan2 downward flt-32 -0x0p+0f 0x0p+0f : -0x0p+0f : inexact-ok
+= atan2 tonearest flt-32 -0x0p+0f 0x0p+0f : -0x0p+0f : inexact-ok
+= atan2 towardzero flt-32 -0x0p+0f 0x0p+0f : -0x0p+0f : inexact-ok
+= atan2 upward flt-32 -0x0p+0f 0x0p+0f : -0x0p+0f : inexact-ok
+= atan2 downward dbl-64 -0x0p+0 0x0p+0 : -0x0p+0 : inexact-ok
+= atan2 tonearest dbl-64 -0x0p+0 0x0p+0 : -0x0p+0 : inexact-ok
+= atan2 towardzero dbl-64 -0x0p+0 0x0p+0 : -0x0p+0 : inexact-ok
+= atan2 upward dbl-64 -0x0p+0 0x0p+0 : -0x0p+0 : inexact-ok
+= atan2 downward ldbl-96-intel -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 upward ldbl-96-intel -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 downward ldbl-96-m68k -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 downward ldbl-128 -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-128 -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-128 -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 upward ldbl-128 -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 downward ldbl-128ibm -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+= atan2 upward ldbl-128ibm -0x0p+0L 0x0p+0L : -0x0p+0L : inexact-ok
+atan2 0 -1
+= atan2 downward flt-32 0x0p+0f -0x1p+0f : 0x3.243f68p+0f : inexact-ok
+= atan2 tonearest flt-32 0x0p+0f -0x1p+0f : 0x3.243f6cp+0f : inexact-ok
+= atan2 towardzero flt-32 0x0p+0f -0x1p+0f : 0x3.243f68p+0f : inexact-ok
+= atan2 upward flt-32 0x0p+0f -0x1p+0f : 0x3.243f6cp+0f : inexact-ok
+= atan2 downward dbl-64 0x0p+0 -0x1p+0 : 0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 tonearest dbl-64 0x0p+0 -0x1p+0 : 0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 towardzero dbl-64 0x0p+0 -0x1p+0 : 0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 upward dbl-64 0x0p+0 -0x1p+0 : 0x3.243f6a8885a32p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 downward ldbl-128 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 upward ldbl-128 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d313198a2e0372p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0x0p+0L -0x1p+0L : 0x3.243f6a8885a308d313198a2e04p+0L : inexact-ok
+atan2 -0 -1
+= atan2 downward flt-32 -0x0p+0f -0x1p+0f : -0x3.243f6cp+0f : inexact-ok
+= atan2 tonearest flt-32 -0x0p+0f -0x1p+0f : -0x3.243f6cp+0f : inexact-ok
+= atan2 towardzero flt-32 -0x0p+0f -0x1p+0f : -0x3.243f68p+0f : inexact-ok
+= atan2 upward flt-32 -0x0p+0f -0x1p+0f : -0x3.243f68p+0f : inexact-ok
+= atan2 downward dbl-64 -0x0p+0 -0x1p+0 : -0x3.243f6a8885a32p+0 : inexact-ok
+= atan2 tonearest dbl-64 -0x0p+0 -0x1p+0 : -0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 towardzero dbl-64 -0x0p+0 -0x1p+0 : -0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 upward dbl-64 -0x0p+0 -0x1p+0 : -0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 downward ldbl-96-intel -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 upward ldbl-96-intel -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 downward ldbl-96-m68k -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 upward ldbl-96-m68k -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 downward ldbl-128 -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 tonearest ldbl-128 -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 towardzero ldbl-128 -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d313198a2e036ep+0L : inexact-ok
+= atan2 upward ldbl-128 -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d313198a2e036ep+0L : inexact-ok
+= atan2 downward ldbl-128ibm -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d313198a2e04p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 upward ldbl-128ibm -0x0p+0L -0x1p+0L : -0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+atan2 0 -0
+= atan2 downward flt-32 0x0p+0f -0x0p+0f : 0x3.243f68p+0f : inexact-ok
+= atan2 tonearest flt-32 0x0p+0f -0x0p+0f : 0x3.243f6cp+0f : inexact-ok
+= atan2 towardzero flt-32 0x0p+0f -0x0p+0f : 0x3.243f68p+0f : inexact-ok
+= atan2 upward flt-32 0x0p+0f -0x0p+0f : 0x3.243f6cp+0f : inexact-ok
+= atan2 downward dbl-64 0x0p+0 -0x0p+0 : 0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 tonearest dbl-64 0x0p+0 -0x0p+0 : 0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 towardzero dbl-64 0x0p+0 -0x0p+0 : 0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 upward dbl-64 0x0p+0 -0x0p+0 : 0x3.243f6a8885a32p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 downward ldbl-128 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 upward ldbl-128 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d313198a2e0372p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0x0p+0L -0x0p+0L : 0x3.243f6a8885a308d313198a2e04p+0L : inexact-ok
+atan2 -0 -0
+= atan2 downward flt-32 -0x0p+0f -0x0p+0f : -0x3.243f6cp+0f : inexact-ok
+= atan2 tonearest flt-32 -0x0p+0f -0x0p+0f : -0x3.243f6cp+0f : inexact-ok
+= atan2 towardzero flt-32 -0x0p+0f -0x0p+0f : -0x3.243f68p+0f : inexact-ok
+= atan2 upward flt-32 -0x0p+0f -0x0p+0f : -0x3.243f68p+0f : inexact-ok
+= atan2 downward dbl-64 -0x0p+0 -0x0p+0 : -0x3.243f6a8885a32p+0 : inexact-ok
+= atan2 tonearest dbl-64 -0x0p+0 -0x0p+0 : -0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 towardzero dbl-64 -0x0p+0 -0x0p+0 : -0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 upward dbl-64 -0x0p+0 -0x0p+0 : -0x3.243f6a8885a3p+0 : inexact-ok
+= atan2 downward ldbl-96-intel -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 upward ldbl-96-intel -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 downward ldbl-96-m68k -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d4p+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 upward ldbl-96-m68k -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308dp+0L : inexact-ok
+= atan2 downward ldbl-128 -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 tonearest ldbl-128 -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d313198a2e037p+0L : inexact-ok
+= atan2 towardzero ldbl-128 -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d313198a2e036ep+0L : inexact-ok
+= atan2 upward ldbl-128 -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d313198a2e036ep+0L : inexact-ok
+= atan2 downward ldbl-128ibm -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d313198a2e04p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+= atan2 upward ldbl-128ibm -0x0p+0L -0x0p+0L : -0x3.243f6a8885a308d313198a2e03p+0L : inexact-ok
+atan2 1 0
+= atan2 downward flt-32 0x1p+0f 0x0p+0f : 0x1.921fb4p+0f : inexact-ok
+= atan2 tonearest flt-32 0x1p+0f 0x0p+0f : 0x1.921fb6p+0f : inexact-ok
+= atan2 towardzero flt-32 0x1p+0f 0x0p+0f : 0x1.921fb4p+0f : inexact-ok
+= atan2 upward flt-32 0x1p+0f 0x0p+0f : 0x1.921fb6p+0f : inexact-ok
+= atan2 downward dbl-64 0x1p+0 0x0p+0 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 tonearest dbl-64 0x1p+0 0x0p+0 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 0x1p+0 0x0p+0 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 0x1p+0 0x0p+0 : 0x1.921fb54442d19p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0x1p+0L 0x0p+0L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0x1p+0L 0x0p+0L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0x1p+0L 0x0p+0L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0x1p+0L 0x0p+0L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0x1p+0L 0x0p+0L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0x1p+0L 0x0p+0L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0x1p+0L 0x0p+0L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0x1p+0L 0x0p+0L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0x1p+0L 0x0p+0L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0x1p+0L 0x0p+0L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0x1p+0L 0x0p+0L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0x1p+0L 0x0p+0L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0x1p+0L 0x0p+0L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0x1p+0L 0x0p+0L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0x1p+0L 0x0p+0L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0x1p+0L 0x0p+0L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+atan2 1 -0
+= atan2 downward flt-32 0x1p+0f -0x0p+0f : 0x1.921fb4p+0f : inexact-ok
+= atan2 tonearest flt-32 0x1p+0f -0x0p+0f : 0x1.921fb6p+0f : inexact-ok
+= atan2 towardzero flt-32 0x1p+0f -0x0p+0f : 0x1.921fb4p+0f : inexact-ok
+= atan2 upward flt-32 0x1p+0f -0x0p+0f : 0x1.921fb6p+0f : inexact-ok
+= atan2 downward dbl-64 0x1p+0 -0x0p+0 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 tonearest dbl-64 0x1p+0 -0x0p+0 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 0x1p+0 -0x0p+0 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 0x1p+0 -0x0p+0 : 0x1.921fb54442d19p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0x1p+0L -0x0p+0L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0x1p+0L -0x0p+0L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0x1p+0L -0x0p+0L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0x1p+0L -0x0p+0L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0x1p+0L -0x0p+0L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0x1p+0L -0x0p+0L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0x1p+0L -0x0p+0L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0x1p+0L -0x0p+0L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0x1p+0L -0x0p+0L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0x1p+0L -0x0p+0L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0x1p+0L -0x0p+0L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0x1p+0L -0x0p+0L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0x1p+0L -0x0p+0L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0x1p+0L -0x0p+0L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0x1p+0L -0x0p+0L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0x1p+0L -0x0p+0L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+atan2 -1 0
+= atan2 downward flt-32 -0x1p+0f 0x0p+0f : -0x1.921fb6p+0f : inexact-ok
+= atan2 tonearest flt-32 -0x1p+0f 0x0p+0f : -0x1.921fb6p+0f : inexact-ok
+= atan2 towardzero flt-32 -0x1p+0f 0x0p+0f : -0x1.921fb4p+0f : inexact-ok
+= atan2 upward flt-32 -0x1p+0f 0x0p+0f : -0x1.921fb4p+0f : inexact-ok
+= atan2 downward dbl-64 -0x1p+0 0x0p+0 : -0x1.921fb54442d19p+0 : inexact-ok
+= atan2 tonearest dbl-64 -0x1p+0 0x0p+0 : -0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 -0x1p+0 0x0p+0 : -0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 -0x1p+0 0x0p+0 : -0x1.921fb54442d18p+0 : inexact-ok
+= atan2 downward ldbl-96-intel -0x1p+0L 0x0p+0L : -0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel -0x1p+0L 0x0p+0L : -0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel -0x1p+0L 0x0p+0L : -0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel -0x1p+0L 0x0p+0L : -0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 downward ldbl-96-m68k -0x1p+0L 0x0p+0L : -0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k -0x1p+0L 0x0p+0L : -0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k -0x1p+0L 0x0p+0L : -0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k -0x1p+0L 0x0p+0L : -0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 downward ldbl-128 -0x1p+0L 0x0p+0L : -0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 -0x1p+0L 0x0p+0L : -0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 -0x1p+0L 0x0p+0L : -0x1.921fb54442d18469898cc51701b7p+0L : inexact-ok
+= atan2 upward ldbl-128 -0x1p+0L 0x0p+0L : -0x1.921fb54442d18469898cc51701b7p+0L : inexact-ok
+= atan2 downward ldbl-128ibm -0x1p+0L 0x0p+0L : -0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm -0x1p+0L 0x0p+0L : -0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm -0x1p+0L 0x0p+0L : -0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm -0x1p+0L 0x0p+0L : -0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+atan2 -1 -0
+= atan2 downward flt-32 -0x1p+0f -0x0p+0f : -0x1.921fb6p+0f : inexact-ok
+= atan2 tonearest flt-32 -0x1p+0f -0x0p+0f : -0x1.921fb6p+0f : inexact-ok
+= atan2 towardzero flt-32 -0x1p+0f -0x0p+0f : -0x1.921fb4p+0f : inexact-ok
+= atan2 upward flt-32 -0x1p+0f -0x0p+0f : -0x1.921fb4p+0f : inexact-ok
+= atan2 downward dbl-64 -0x1p+0 -0x0p+0 : -0x1.921fb54442d19p+0 : inexact-ok
+= atan2 tonearest dbl-64 -0x1p+0 -0x0p+0 : -0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 -0x1p+0 -0x0p+0 : -0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 -0x1p+0 -0x0p+0 : -0x1.921fb54442d18p+0 : inexact-ok
+= atan2 downward ldbl-96-intel -0x1p+0L -0x0p+0L : -0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel -0x1p+0L -0x0p+0L : -0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel -0x1p+0L -0x0p+0L : -0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel -0x1p+0L -0x0p+0L : -0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 downward ldbl-96-m68k -0x1p+0L -0x0p+0L : -0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k -0x1p+0L -0x0p+0L : -0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k -0x1p+0L -0x0p+0L : -0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k -0x1p+0L -0x0p+0L : -0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 downward ldbl-128 -0x1p+0L -0x0p+0L : -0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 -0x1p+0L -0x0p+0L : -0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 -0x1p+0L -0x0p+0L : -0x1.921fb54442d18469898cc51701b7p+0L : inexact-ok
+= atan2 upward ldbl-128 -0x1p+0L -0x0p+0L : -0x1.921fb54442d18469898cc51701b7p+0L : inexact-ok
+= atan2 downward ldbl-128ibm -0x1p+0L -0x0p+0L : -0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm -0x1p+0L -0x0p+0L : -0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm -0x1p+0L -0x0p+0L : -0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm -0x1p+0L -0x0p+0L : -0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+atan2 max max
+= atan2 downward flt-32 0xf.fffffp+124f 0xf.fffffp+124f : 0xc.90fdap-4f : inexact-ok
+= atan2 tonearest flt-32 0xf.fffffp+124f 0xf.fffffp+124f : 0xc.90fdbp-4f : inexact-ok
+= atan2 towardzero flt-32 0xf.fffffp+124f 0xf.fffffp+124f : 0xc.90fdap-4f : inexact-ok
+= atan2 upward flt-32 0xf.fffffp+124f 0xf.fffffp+124f : 0xc.90fdbp-4f : inexact-ok
+= atan2 downward dbl-64 0xf.fffffp+124 0xf.fffffp+124 : 0xc.90fdaa22168cp-4 : inexact-ok
+= atan2 tonearest dbl-64 0xf.fffffp+124 0xf.fffffp+124 : 0xc.90fdaa22168cp-4 : inexact-ok
+= atan2 towardzero dbl-64 0xf.fffffp+124 0xf.fffffp+124 : 0xc.90fdaa22168cp-4 : inexact-ok
+= atan2 upward dbl-64 0xf.fffffp+124 0xf.fffffp+124 : 0xc.90fdaa22168c8p-4 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234c4c6628b80dc8p-4L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234c4c6628b80cp-4L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234c4c6628b80cp-4L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234c4c6628b80cp-4L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.fffffp+124L 0xf.fffffp+124L : 0xc.90fdaa22168c234c4c6628b81p-4L : inexact-ok
+= atan2 downward dbl-64 0xf.fffffp+124 0xf.ffffffffffff8p+1020 : 0xf.fffffp-900 : inexact-ok
+= atan2 tonearest dbl-64 0xf.fffffp+124 0xf.ffffffffffff8p+1020 : 0xf.fffff00000008p-900 : inexact-ok
+= atan2 towardzero dbl-64 0xf.fffffp+124 0xf.ffffffffffff8p+1020 : 0xf.fffffp-900 : inexact-ok
+= atan2 upward dbl-64 0xf.fffffp+124 0xf.ffffffffffff8p+1020 : 0xf.fffff00000008p-900 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007ffp-900L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000008p-900L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007ffp-900L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000008p-900L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007ffp-900L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000008p-900L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007ffp-900L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000008p-900L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007fffff80000003f8p-900L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007fffff80000004p-900L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007fffff80000003f8p-900L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007fffff80000004p-900L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007fffff8p-900L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007fffff80000004p-900L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007fffff8p-900L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.fffffp+124L 0xf.ffffffffffff8p+1020L : 0xf.fffff00000007fffff80000004p-900L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffffp-16260L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffff0000000001p-16260L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffffp-16260L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffff0000000001p-16260L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffffp-16260L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffff0000000001p-16260L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffffp-16260L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffff0000000001p-16260L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffff0000000000ffffffp-16260L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffff0000000000ffffffp-16260L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffff0000000000ffffffp-16260L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0xf.fffffffffffffffp+16380L : 0xf.fffff0000000000ffffff0000008p-16260L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.fffffp-16260L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.fffff00000000000000000000008p-16260L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.fffffp-16260L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.fffff00000000000000000000008p-16260L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xf.fffff00000003fffffc0000004f8p-900L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xf.fffff00000003fffffc0000005p-900L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xf.fffff00000003fffffc0000004f8p-900L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xf.fffff00000003fffffc0000005p-900L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.fffffp+124L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xf.fffff00000003fffffc0000004p-900L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.fffffp+124L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xf.fffff00000003fffffc0000004p-900L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.fffffp+124L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xf.fffff00000003fffffc0000004p-900L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.fffffp+124L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xf.fffff00000003fffffc0000008p-900L : inexact-ok
+= atan2 downward dbl-64 0xf.ffffffffffff8p+1020 0xf.fffffp+124 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 tonearest dbl-64 0xf.ffffffffffff8p+1020 0xf.fffffp+124 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 0xf.ffffffffffff8p+1020 0xf.fffffp+124 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 0xf.ffffffffffff8p+1020 0xf.fffffp+124 : 0x1.921fb54442d19p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 downward dbl-64 0xf.ffffffffffff8p+1020 0xf.ffffffffffff8p+1020 : 0xc.90fdaa22168cp-4 : inexact-ok
+= atan2 tonearest dbl-64 0xf.ffffffffffff8p+1020 0xf.ffffffffffff8p+1020 : 0xc.90fdaa22168cp-4 : inexact-ok
+= atan2 towardzero dbl-64 0xf.ffffffffffff8p+1020 0xf.ffffffffffff8p+1020 : 0xc.90fdaa22168cp-4 : inexact-ok
+= atan2 upward dbl-64 0xf.ffffffffffff8p+1020 0xf.ffffffffffff8p+1020 : 0xc.90fdaa22168c8p-4 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234c4c6628b80dc8p-4L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234c4c6628b80cp-4L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234c4c6628b80cp-4L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234c4c6628b80cp-4L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c234c4c6628b81p-4L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff8p-15364L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff801p-15364L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff8p-15364L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff801p-15364L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff8p-15364L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff801p-15364L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff8p-15364L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff801p-15364L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff800ffffffffffff8p-15364L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff801p-15364L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff800ffffffffffff8p-15364L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffff801p-15364L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.ffffffffffff8p-15364L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.ffffffffffff8000000000000008p-15364L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.ffffffffffff8p-15364L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.ffffffffffff8000000000000008p-15364L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c034c4c6628b80fp-4L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c034c4c6628b80fp-4L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c034c4c6628b80fp-4L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c034c4c6628b80f08p-4L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c034c4c6628b80cp-4L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c034c4c6628b81p-4L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c034c4c6628b80cp-4L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c034c4c6628b81p-4L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c234p-4L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c235p-4L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c234c4c6628b80dc8p-4L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xc.90fdaa22168c23444c6628b80dcp-4L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xc.90fdaa22168c23444c6628b80dc8p-4L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xc.90fdaa22168c23444c6628b80dcp-4L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xc.90fdaa22168c23444c6628b80dc8p-4L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.ffffffffffffbffffffffffffcp+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffp+16380L 0xf.ffffffffffffbffffffffffffcp+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffp+16380L 0xf.ffffffffffffbffffffffffffcp+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffp+16380L 0xf.ffffffffffffbffffffffffffcp+1020L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.ffffffffffff8p+1020L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c23544c6628b80db8p-4L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c23544c6628b80dcp-4L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c23544c6628b80db8p-4L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffffffffffffp+16380L : 0xc.90fdaa22168c23544c6628b80dcp-4L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xc.90fdaa22168c234c4c6628b80dc8p-4L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.ffffffffffffbffffffffffffcp+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.ffffffffffffbffffffffffffcp+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.ffffffffffffbffffffffffffcp+1020L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffffffffffffff8p+16380L 0xf.ffffffffffffbffffffffffffcp+1020L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffp+124L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c434c4c6628b80c8p-4L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c434c4c6628b80c8p-4L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c434c4c6628b80c8p-4L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c434c4c6628b80c88p-4L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c434c4c6628b80cp-4L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c434c4c6628b80cp-4L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c434c4c6628b80cp-4L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffff8p+1020L : 0xc.90fdaa22168c434c4c6628b81p-4L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffffc00ffffffffffbf8p-15364L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffffc00ffffffffffcp-15364L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffffc00ffffffffffbf8p-15364L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffffffffffffp+16380L : 0xf.ffffffffffffc00ffffffffffcp-15364L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.ffffffffffffbffffffffffffcp-15364L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.ffffffffffffbffffffffffffc08p-15364L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.ffffffffffffbffffffffffffcp-15364L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.fffffffffffffffffffffffffff8p+16380L : 0xf.ffffffffffffbffffffffffffc08p-15364L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c234c4c6628b80dcp-4L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c234c4c6628b80dc8p-4L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c234c4c6628b80cp-4L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c234c4c6628b80cp-4L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c234c4c6628b80cp-4L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.ffffffffffffbffffffffffffcp+1020L 0xf.ffffffffffffbffffffffffffcp+1020L : 0xc.90fdaa22168c234c4c6628b81p-4L : inexact-ok
+atan2 max min
+= atan2 downward flt-32 0xf.fffffp+124f 0x4p-128f : 0x1.921fb4p+0f : inexact-ok
+= atan2 tonearest flt-32 0xf.fffffp+124f 0x4p-128f : 0x1.921fb6p+0f : inexact-ok
+= atan2 towardzero flt-32 0xf.fffffp+124f 0x4p-128f : 0x1.921fb4p+0f : inexact-ok
+= atan2 upward flt-32 0xf.fffffp+124f 0x4p-128f : 0x1.921fb6p+0f : inexact-ok
+= atan2 downward dbl-64 0xf.fffffp+124 0x4p-128 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 tonearest dbl-64 0xf.fffffp+124 0x4p-128 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 0xf.fffffp+124 0x4p-128 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 0xf.fffffp+124 0x4p-128 : 0x1.921fb54442d19p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.fffffp+124L 0x4p-128L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 downward dbl-64 0xf.fffffp+124 0x4p-1024 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 tonearest dbl-64 0xf.fffffp+124 0x4p-1024 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 0xf.fffffp+124 0x4p-1024 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 0xf.fffffp+124 0x4p-1024 : 0x1.921fb54442d19p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.fffffp+124L 0x4p-1024L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0x4p-16384L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0x2p-16384L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward dbl-64 0xf.fffffp+124 0x8p-972 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 tonearest dbl-64 0xf.fffffp+124 0x8p-972 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 0xf.fffffp+124 0x8p-972 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 0xf.fffffp+124 0x8p-972 : 0x1.921fb54442d19p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.fffffp+124L 0x8p-972L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 downward dbl-64 0xf.ffffffffffff8p+1020 0x4p-128 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 tonearest dbl-64 0xf.ffffffffffff8p+1020 0x4p-128 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 0xf.ffffffffffff8p+1020 0x4p-128 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 0xf.ffffffffffff8p+1020 0x4p-128 : 0x1.921fb54442d19p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x4p-128L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 downward dbl-64 0xf.ffffffffffff8p+1020 0x4p-1024 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 tonearest dbl-64 0xf.ffffffffffff8p+1020 0x4p-1024 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 0xf.ffffffffffff8p+1020 0x4p-1024 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 0xf.ffffffffffff8p+1020 0x4p-1024 : 0x1.921fb54442d19p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x4p-1024L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0x4p-16384L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0x2p-16384L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward dbl-64 0xf.ffffffffffff8p+1020 0x8p-972 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 tonearest dbl-64 0xf.ffffffffffff8p+1020 0x8p-972 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 towardzero dbl-64 0xf.ffffffffffff8p+1020 0x8p-972 : 0x1.921fb54442d18p+0 : inexact-ok
+= atan2 upward dbl-64 0xf.ffffffffffff8p+1020 0x8p-972 : 0x1.921fb54442d19p+0 : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 tonearest ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 towardzero ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18469898cc517018p+0L : inexact-ok
+= atan2 upward ldbl-128ibm 0xf.ffffffffffff8p+1020L 0x8p-972L : 0x1.921fb54442d18469898cc51702p+0L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-intel 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 upward ldbl-96-m68k 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 downward ldbl-128 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 tonearest ldbl-128 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 towardzero ldbl-128 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d18469898cc51701b8p+0L : inexact-ok
+= atan2 upward ldbl-128 0xf.fffffffffffffffp+16380L 0x4p-128L : 0x1.921fb54442d18469898cc51701b9p+0L : inexact-ok
+= atan2 downward ldbl-96-intel 0xf.fffffffffffffffp+16380L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
+= atan2 tonearest ldbl-96-intel 0xf.fffffffffffffffp+16380L 0x4p-1024L : 0x1.921fb54442d1846ap+0L : inexact-ok
+= atan2 towardzero ldbl-96-intel 0xf.fffffffffffffffp+16380L 0x4p-1024L : 0x1.921fb54442d18468p+0L : inexact-ok
[... 43193 lines stripped ...]
_______________________________________________
Commits mailing list
Commits@xxxxxxxxxx
http://eglibc.org/cgi-bin/mailman/listinfo/commits
--- fsf/trunk/libc/elf/dl-error.c (original)
+++ fsf/trunk/libc/elf/dl-error.c Tue Dec 17 00:02:09 2013
@@ -28,10 +28,11 @@
_dl_signal_error. */
struct catch
{
- const char *objname; /* Object/File name. */
- const char *errstring; /* Error detail filled in here. */
- bool malloced; /* Nonzero if the string is malloced
+ const char **objname; /* Object/File name. */
+ const char **errstring; /* Error detail filled in here. */
+ bool *malloced; /* Nonzero if the string is malloced
by the libc malloc. */
+ volatile int *errcode; /* Return value of _dl_signal_error. */
jmp_buf env; /* longjmp here on error. */
};
@@ -86,33 +87,36 @@
size_t len_objname = strlen (objname) + 1;
size_t len_errstring = strlen (errstring) + 1;
- lcatch->errstring = (char *) malloc (len_objname + len_errstring);
- if (lcatch->errstring != NULL)
+ char *errstring_copy = malloc (len_objname + len_errstring);
+ if (errstring_copy != NULL)
{
/* Make a copy of the object file name and the error string. */
- lcatch->objname = memcpy (__mempcpy ((char *) lcatch->errstring,
- errstring, len_errstring),
- objname, len_objname);
+ *lcatch->objname = memcpy (__mempcpy (errstring_copy,
+ errstring, len_errstring),
+ objname, len_objname);
+ *lcatch->errstring = errstring_copy;
/* If the main executable is relocated it means the libc's malloc
is used. */
+ bool malloced = true;
#ifdef SHARED
- lcatch->malloced = (GL(dl_ns)[LM_ID_BASE]._ns_loaded != NULL
- && (GL(dl_ns)[LM_ID_BASE]._ns_loaded->l_relocated
- != 0));
-#else
- lcatch->malloced = true;
+ malloced = (GL(dl_ns)[LM_ID_BASE]._ns_loaded != NULL
+ && (GL(dl_ns)[LM_ID_BASE]._ns_loaded->l_relocated != 0));
#endif
+ *lcatch->malloced = malloced;
}
else
{
/* This is better than nothing. */
- lcatch->objname = "";
- lcatch->errstring = _dl_out_of_memory;
- lcatch->malloced = false;
+ *lcatch->objname = "";
+ *lcatch->errstring = _dl_out_of_memory;
+ *lcatch->malloced = false;
}
+
+ *lcatch->errcode = errcode;
+
/* We do not restore the signal mask because none was saved. */
- __longjmp (lcatch->env[0].__jmpbuf, errcode ?: -1);
+ __longjmp (lcatch->env[0].__jmpbuf, 1);
}
else
{
@@ -157,23 +161,29 @@
_dl_catch_error (const char **objname, const char **errstring,
bool *mallocedp, void (*operate) (void *), void *args)
{
- int errcode;
- struct catch *volatile old;
- struct catch c;
/* We need not handle `receiver' since setting a `catch' is handled
before it. */
- /* Some systems (e.g., SPARC) handle constructors to local variables
- inefficient. So we initialize `c' by hand. */
- c.errstring = NULL;
+ /* Only this needs to be marked volatile, because it is the only local
+ variable that gets changed between the setjmp invocation and the
+ longjmp call. All others are just set here (before setjmp) and read
+ in _dl_signal_error (before longjmp). */
+ volatile int errcode;
+
+ struct catch c;
+ /* Don't use an initializer since we don't need to clear C.env. */
+ c.objname = objname;
+ c.errstring = errstring;
+ c.malloced = mallocedp;
+ c.errcode = &errcode;
struct catch **const catchp = &CATCH_HOOK;
- old = *catchp;
+ struct catch *const old = *catchp;
+ *catchp = &c;
+
/* Do not save the signal mask. */
- errcode = __sigsetjmp (c.env, 0);
- if (__builtin_expect (errcode, 0) == 0)
- {
- *catchp = &c;
+ if (__builtin_expect (__sigsetjmp (c.env, 0), 0) == 0)
+ {
(*operate) (args);
*catchp = old;
*objname = NULL;
@@ -182,12 +192,10 @@
return 0;
}
- /* We get here only if we longjmp'd out of OPERATE. */
+ /* We get here only if we longjmp'd out of OPERATE. _dl_signal_error has
+ already stored values into *OBJNAME, *ERRSTRING, and *MALLOCEDP. */
*catchp = old;
- *objname = c.objname;
- *errstring = c.errstring;
- *mallocedp = c.malloced;
- return errcode == -1 ? 0 : errcode;
+ return errcode;
}
Modified: fsf/trunk/libc/manual/memory.texi
==============================================================================